@@ -3,6 +3,7 @@ ripper = shtRipper_entry.Ripper()
 
 import time
 import json
+import math
 
 filename = 'd:/data/cfm/original/sht40808.SHT'
 
@@ -34,18 +35,27 @@ with open('%s%d.json' % (path, shotn), 'r') as file:
 
 
 to_pack = {
-    'central Te': {
-        'comment': 'Температура в центре',
+    'signal with error': {
+        'comment': 'Точки хранят ещё и погрешность, требует много памяти.',
         'unit': 'T_e(eV)',
         'x': x,
         'y': T_c,
         'err': T_err
     },
-    'signal 2': {
-        'comment': 'ne в центре',
+    'X Y signal': {
+        'comment': 'Точки хранятся парой значений, требует много памяти.',
         'unit': 'T_e(eV)',
         'x': x,
         'y': n_c
+    },
+    'Y signal with fixed X-grid': {
+        'comment': 'Этот тип хранения данных предназначен для данных 16-бит АЦП',
+        'unit': 'U(V)',
+        'tMin': 0.0,
+        'tMax': 100.0,
+        'offset': 0.0,  # ADC zero level offset
+        'yRes': 0.0001,  # ADC resolution: 0.0001 Volt per adc bit
+        'y': [math.sin(i / 10) for i in range(100)]
     }
 }
 
